==> Botan-1.1.10.tgz: Botan-1.1.10/src/blinding.cpp <==
/*************************************************
* Blinder Source File                            *
* (C) 1999-2003 The Botan Project                *
*************************************************/

#include <botan/blinding.h>
#include <botan/numthry.h>
#include <botan/conf.h>

namespace Botan {

/*************************************************
* Blinder Constructor                            *
*************************************************/
Blinder::Blinder()
   {
   reducer = 0;
   do_blinding = false;
   }

/*************************************************
* Blinder Copy Constructor                       *
*************************************************/
Blinder::Blinder(const Blinder& blinder)
   {
   reducer = 0;
   do_blinding = Config::get_bool("base/do_blinding");

   if(!do_blinding)
      return;

   e = blinder.e;
   d = blinder.d;
   n = blinder.n;
   reducer = get_reducer(n);
   }

/*************************************************
* Blinder Assignment Operator                    *
*************************************************/
Blinder& Blinder::operator=(const Blinder& blinder)
   {
   delete reducer;
   if(!blinder.do_blinding)
      {
      do_blinding = false;
      return (*this);
      }

   e = blinder.e;
   d = blinder.d;
   n = blinder.n;
   reducer = get_reducer(n);
   return (*this);
   }

/*************************************************
* Initialize a Blinder object                    *
*************************************************/
void Blinder::initialize(const BigInt& e1, const BigInt& d1, const BigInt& n1)
   {
   delete reducer;
   do_blinding = Config::get_bool("base/do_blinding");

   if(!do_blinding)
      return;

   e = e1;
   d = d1;
   n = n1;
   reducer = get_reducer(n);
   }

/*************************************************
* Blinder Destructor                             *
*************************************************/
Blinder::~Blinder()
   {
   delete reducer;
   }

/*************************************************
* Blind a number                                 *
*************************************************/
BigInt Blinder::blind(const BigInt& i) const
   {
   if(!do_blinding) return i;
   update();
   return reducer->multiply(i, e);
   }

/*************************************************
* Unblind a number                               *
*************************************************/
BigInt Blinder::unblind(const BigInt& i) const
   {
   if(!do_blinding) return i;
   return reducer->multiply(i, d);
   }

/*************************************************
* Create a new blinding/unblinding pair          *
*************************************************/
void Blinder::update() const
   {
   if(!do_blinding) return;
   e = reducer->square(e);
   d = reducer->square(d);
   }

}

==> Botan-1.3.6.tgz: Botan-1.3.6/src/blinding.cpp <==
/*************************************************
* Blinder Source File                            *
* (C) 1999-2003 The Botan Project                *
*************************************************/

#include <botan/blinding.h>
#include <botan/numthry.h>
#include <botan/conf.h>

namespace Botan {

/*************************************************
* Blinder Constructor                            *
*************************************************/
Blinder::Blinder()
   {
   reducer = 0;
   do_blinding = false;
   }

/*************************************************
* Blinder Copy Constructor                       *
*************************************************/
Blinder::Blinder(const Blinder& blinder)
   {
   reducer = 0;
   if(Config::get_bool("base/do_blinding"))
      initialize(blinder.e, blinder.d, blinder.n);
   }

/*************************************************
* Blinder Assignment Operator                    *
*************************************************/
Blinder& Blinder::operator=(const Blinder& blinder)
   {
   if(blinder.do_blinding)
      initialize(blinder.e, blinder.d, blinder.n);
   return (*this);
   }

/*************************************************
* Initialize a Blinder object                    *
*************************************************/
void Blinder::initialize(const BigInt& e1, const BigInt& d1, const BigInt& n1)
   {
   delete reducer;
   do_blinding = Config::get_bool("base/do_blinding");

   if(!do_blinding)
      return;

   e = e1;
   d = d1;
   n = n1;
   reducer = get_reducer(n);
   }

/*************************************************
* Blinder Destructor                             *
*************************************************/
Blinder::~Blinder()
   {
   delete reducer;
   }

/*************************************************
* Blind a number                                 *
*************************************************/
BigInt Blinder::blind(const BigInt& i) const
   {
   if(!do_blinding) return i;
   e = reducer->square(e);
   d = reducer->square(d);
   return reducer->multiply(i, e);
   }

/*************************************************
* Unblind a number                               *
*************************************************/
BigInt Blinder::unblind(const BigInt& i) const
   {
   if(!do_blinding) return i;
   return reducer->multiply(i, d);
   }

}
